@@ -1,9 +1,9 @@
 # -*-cperl-*-
 #
 # Crypt::RSA::Blind - Blind RSA signatures
-# Copyright (c) 2016-2017 Ashish Gulhati <crypt-rsab at hash.neo.tc>
+# Copyright (c) Ashish Gulhati <crypt-rsab at hash.neo.tc>
 #
-# $Id: lib/Crypt/RSA/Blind.pm v1.009 Sat Jun 10 00:16:58 PDT 2017 $
+# $Id: lib/Crypt/RSA/Blind.pm v1.010 Sat Oct 27 21:19:50 PDT 2018 $
 
 package Crypt::RSA::Blind;
 
@@ -16,7 +16,7 @@ use Crypt::Random qw(makerandom_itv makerandom);
 use Math::Pari qw (Mod component);
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.009 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.010 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   bless { HASHSIZE  => 768,
@@ -132,8 +132,8 @@ Crypt::RSA::Blind - Blind RSA signatures
 
 =head1 VERSION
 
- $Revision: 1.009 $
- $Date: Sat Jun 10 00:16:58 PDT 2017 $
+ $Revision: 1.010 $
+ $Date: Sat Oct 27 21:19:50 PDT 2018 $
 
 =cut
 
@@ -310,11 +310,12 @@ L<http://search.cpan.org/dist/Crypt-RSA-Blind/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2016-2017 Ashish Gulhati.
+Copyright (c) Ashish Gulhati.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License 2.0.
-
-See http://www.perlfoundation.org/artistic_license_2_0 for the full
-license terms.
+This software package is Open Software; you can use, redistribute,
+and/or modify it under the terms of the Open Artistic License 2.0.
 
+Please see L<http://www.opensoftwr.org/oal20.txt> for the full license
+terms, and ensure that the license grant applies to you before using
+or modifying this software. By using or modifying this software, you
+indicate your agreement with the license terms.
